@@ -52,6 +52,13 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
 
 [TOC]
 
+@section curl_0 Overview
+
+The CURL plugin for gSOAP provides a bridge for the gSOAP engine to use libcurl
+for internet communications.  While gSOAP provides a full HTTP stack, libcurl
+can be used to support additional protocols and features by replacing gSOAP's
+HTTP stack.
+
 @section curl_1 CURL plugin setup
 
 To use the CURL plugin:
@@ -471,9 +478,9 @@ static int soap_curl_connect_callback(struct soap *soap, const char *endpoint, c
   {
     if (soap_http_content_type(soap, SOAP_OK))
     {
-      soap_memmove(soap->tmpbuf+14, sizeof(soap->tmpbuf), soap->tmpbuf, sizeof(soap->tmpbuf)-14);
+      (void)soap_memmove(soap->tmpbuf+14, sizeof(soap->tmpbuf), soap->tmpbuf, sizeof(soap->tmpbuf)-14);
       soap->tmpbuf[sizeof(soap->tmpbuf)-1] = '\0';
-      soap_memcpy(soap->tmpbuf, sizeof(soap->tmpbuf), "Content-Type: ", 14);
+      (void)soap_memcpy(soap->tmpbuf, sizeof(soap->tmpbuf), "Content-Type: ", 14);
       data->hdr = curl_slist_append(data->hdr, soap->tmpbuf);
       curl_easy_setopt(data->curl, CURLOPT_HTTPHEADER, (void*)data->hdr);
     }
@@ -535,10 +542,13 @@ static int soap_curl_send_callback(struct soap *soap, const char *buf, size_t le
     return soap->error = SOAP_PLUGIN_ERROR;
   if (!data->active)
     return data->fsend(soap, buf, len);
-  blk = (char*)soap_push_block(soap, data->lst, len);
-  if (!blk)
-    return soap->error;
-  soap_memcpy((void*)blk, len, (const void*)buf, len);
+  if (len > 0)
+  {
+    blk = (char*)soap_push_block(soap, data->lst, len);
+    if (!blk)
+      return soap->error;
+    (void)soap_memcpy((void*)blk, len, (const void*)buf, len);
+  }
   return SOAP_OK;
 }
 
@@ -551,6 +561,8 @@ static int soap_curl_send_callback(struct soap *soap, const char *buf, size_t le
 static int soap_curl_prepare_init_recv_callback(struct soap *soap)
 {
   struct soap_curl_data *data = (struct soap_curl_data*)soap_lookup_plugin(soap, soap_curl_id);
+  long status;
+  const char *s = NULL;
   DBGFUN("soap_curl_prepare_init_recv_callback");
   if (!data || !data->curl)
     return soap->error = SOAP_PLUGIN_ERROR;
@@ -585,9 +597,22 @@ static int soap_curl_prepare_init_recv_callback(struct soap *soap)
   data->hdr = NULL;
   if (res != CURLE_OK)
     return soap_sender_fault(soap, curl_easy_strerror(res), "origin: soap_curl plugin");
-  if (data->fprepareinitrecv)
-    return data->fprepareinitrecv(soap);
-  return SOAP_OK;
+  curl_easy_getinfo(data->curl, CURLINFO_RESPONSE_CODE, &status);
+  if (!curl_easy_getinfo(data->curl, CURLINFO_CONTENT_TYPE, &s) && s)
+    soap->http_content = soap_strdup(soap, s);
+  DBGLOG(TEST, SOAP_MESSAGE(fdebug, "cURL HTTP response code %ld content type %s\n", status, s ? s : ""));
+  soap->status = (int)status;
+  if ((soap->status >= 200 && soap->status <= 299) /* OK, Accepted, etc */
+   || soap->status == 400                          /* Bad Request */
+   || soap->status == 500)                         /* Internal Server Error */
+  {
+    if (data->fprepareinitrecv)
+      return data->fprepareinitrecv(soap);
+    return SOAP_OK;
+  }
+  /* read HTTP body for error details */
+  s = soap_get_http_body(soap, NULL);
+  return soap_set_receiver_error(soap, "HTTP Error", s, soap->status);
 }
 
 /**
@@ -650,7 +675,7 @@ static size_t soap_curl_recv_callback(struct soap *soap, char *buf, size_t size)
   len = soap_block_size(soap, data->lst) - (data->ptr - data->blk);
   if (len > size)
     len = size;
-  soap_memcpy((void*)buf, size, (const void*)data->ptr, len);
+  (void)soap_memcpy((void*)buf, size, (const void*)data->ptr, len);
   data->ptr += len;
   if (data->ptr >= data->blk + soap_block_size(data->soap, data->lst))
   {
@@ -661,6 +686,7 @@ static size_t soap_curl_recv_callback(struct soap *soap, char *buf, size_t size)
       data->lst = NULL;
     }
   }
+  soap->length += len;
   return len;
 }
 
@@ -700,7 +726,7 @@ static size_t soap_curl_read_callback(void *buffer, size_t size, size_t nitems,
   len = soap_block_size(soap, data->lst) - (data->ptr - data->blk);
   if (len > size * nitems)
     len = size * nitems;
-  soap_memcpy((void*)buffer, size * nitems, (const void*)data->ptr, len);
+  (void)soap_memcpy((void*)buffer, size * nitems, (const void*)data->ptr, len);
   data->ptr += len;
   if (data->ptr >= data->blk + soap_block_size(soap, data->lst))
   {
@@ -735,7 +761,7 @@ static size_t soap_curl_write_callback(void *buffer, size_t size, size_t nitems,
   s = (char*)soap_push_block(soap, data->lst, len);
   if (!s)
     return 0;
-  soap_memcpy((void*)s, len, buffer, len);
+  (void)soap_memcpy((void*)s, len, buffer, len);
   return len;
 }
 
