@@ -571,7 +571,7 @@ static void soap_wsa_delete(struct soap *soap, struct soap_plugin *p);
 
 static int soap_wsa_header(struct soap *soap);
 static void soap_wsa_set_error(struct soap *soap, const char **c, const char **s);
-static int soap_wsa_response(struct soap *soap, int status, size_t count);
+static int soap_wsa_response(struct soap *soap, int status, ULONG64 count);
 static int soap_wsa_disconnect(struct soap *soap);
 
 static int soap_wsa_alloc_header(struct soap *soap);
@@ -959,7 +959,7 @@ soap_wsa_reply(struct soap *soap, const char *id, const char *action)
       {
         soap_copy_stream(reply_soap, soap);
         soap_free_stream(soap); /* prevents close in soap_connect() below */
-        soap->omode |= SOAP_ENC_XML; /* omit HTTP header ("encode XML body only") */
+        soap->omode |= SOAP_ENC_PLAIN; /* omit HTTP header ("encode XML body only") */
         if (soap_connect(soap, newheader->SOAP_WSA(To), newheader->SOAP_WSA(Action)))
         {
           int err;
@@ -981,7 +981,7 @@ soap_wsa_reply(struct soap *soap, const char *id, const char *action)
         if (soap_valid_socket(reply_soap->socket))
           soap_send_empty_response(reply_soap, SOAP_OK);        /* HTTP ACCEPTED */
         soap->header = newheader;
-        soap->omode &= ~SOAP_ENC_XML;           /* HTTP header required */
+        soap->omode &= ~SOAP_ENC_PLAIN;           /* HTTP header required */
         soap_end(reply_soap);
         soap_free(reply_soap);
         data->fresponse = soap->fresponse;
@@ -1501,7 +1501,7 @@ soap_wsa_error(struct soap *soap, SOAP_WSA(FaultSubcodeValues) fault)
 
 /**
 @fn int soap_wsa(struct soap *soap, struct soap_plugin *p, void *arg)
-@brief Plugin registry function, used with soap_register_plugin.
+@brief Plugin registry function, used with soap_register_plugin and soap_register_plugin_arg.
 @param soap context
 @param[in,out] p plugin created in registry
 @param[in] arg passed from soap_register_plugin_arg
@@ -1633,14 +1633,14 @@ soap_wsa_set_error(struct soap *soap, const char **c, const char **s)
 /******************************************************************************/
 
 /**
-@fn int soap_wsa_response(struct soap *soap, int status, size_t count)
+@fn int soap_wsa_response(struct soap *soap, int status, ULONG64 count)
 @brief Overrides the HTTP response operations to send an HTTP POST
 @param soap context
 @param status code
 @param count message length (if non-chunked)
 */
 static int
-soap_wsa_response(struct soap *soap, int status, size_t count)
+soap_wsa_response(struct soap *soap, int status, ULONG64 count)
 {
   struct soap_wsa_data *data = (struct soap_wsa_data*)soap_lookup_plugin(soap, soap_wsa_id);
   (void)status;
@@ -1686,6 +1686,8 @@ soap_wsa_disconnect(struct soap *soap)
 static int
 soap_wsa_alloc_header(struct soap *soap)
 {
+  if (soap->header)
+    return SOAP_OK;
   soap_header(soap);
   if (soap->header)
     return SOAP_OK;
