@@ -1,9 +1,9 @@
 /*
-	wsddapi.c
+        wsddapi.c
 
-	WS-Discovery 1.0 and 1.1 (WSDD) plugin API
+        WS-Discovery 1.0 and 1.1 (WSDD) plugin API
 
-	See gsoap/doc/wsdd for the WSDD plugin user guide.
+        See gsoap/doc/wsdd for the WSDD plugin user guide.
 
 gSOAP XML Web services tools
 Copyright (C) 2000-2011, Robert van Engelen, Genivia Inc., All Rights Reserved.
@@ -82,8 +82,8 @@ higher-level logic remains application-specific. Especially the mode of
 operation, ad-hoc or managed with a Discovery Proxy, depends on the application
 deployment and WS-Discovery support requirements.
 
-The following assumptions are made. A Client is an endpoint that searches for
-Target Service(s). A Target Service (TS) is and endpoint that makes itself
+The following assumptions are made. A Client (C) is an endpoint that searches for
+Target Service(s). A Target Service (TS) is a service endpoint that makes itself
 available for discovery. A Discovery Proxy (DP) is an endpoint that facilitates
 discovery of Target Services by Clients. The interfaces defined in the wsdd
 library can be used to implement Client, Target Service, and Discovery Proxy
@@ -135,7 +135,8 @@ periodically polling the port as shown:
     struct soap *soap = soap_new();
     soap->user = (void*)&my_state;
     if (!soap_valid_socket(soap_bind(soap, port, 100)))
-    { soap_print_fault(soap, stderr);
+    {
+      soap_print_fault(soap, stderr);
       exit(0);
     }
 
@@ -314,44 +315,59 @@ that is accessible in the soap->peer and soap->peerlen members. For example:
 
 @section wsdd_5 Generating C++ Server Objects
 
-The WSDD library is developed to support C and C++. To support C++ server
-objects generated with soapcpp2 options `-j` (or `-i`), you need to define in your
-C++ code the following wrappers (use `this` instead of `this->soap` below with
-soapcpp2 option `-i`):
+The WSDD plugin is developed to support C and C++. To support C++ server
+objects generated with soapcpp2 option `-j` (or `-i`), run soapcpp2 again:
+
+    soapcpp2 -a -j -Iimport import/wsdd.h
+
+You should define in your C++ code the following wrappers (use `this` instead
+of `this->soap` below with soapcpp2 option `-i`):
 
 @code
     int wsddService::Hello(struct wsdd__HelloType *hello)
-    { return __wsdd__Hello(this->soap, hello);
+    {
+      return __wsdd__Hello(this->soap, hello);
     }
-    int wsddService::Bye(struct wsdd__ByeType *bye
-    { return __wsdd__Bye(this->soap, bye);
+    int wsddService::Bye(struct wsdd__ByeType *bye)
+    {
+      return __wsdd__Bye(this->soap, bye);
     }
     int wsddService::Probe(struct wsdd__ProbeType *probe)
-    { return __wsdd__Probe(this->soap, probe);
+    {
+      return __wsdd__Probe(this->soap, probe);
     }
     int wsddService::ProbeMatches(struct wsdd__ProbeMatchesType *matches)
-    { return __wsdd__ProbeMatches(this->soap, matches);
+    {
+      return __wsdd__ProbeMatches(this->soap, matches);
     }
     int wsddService::Resolve(struct wsdd__ResolveType *resolve)
-    { return __wsdd__Resolve(this->soap, resolve);
+    {
+      return __wsdd__Resolve(this->soap, resolve);
     }
-    int wsddService::ResolveProbeMatches(struct wsdd__ResolveMatchesType *matches)
-    { return __wsdd__ResolveMatches(this->soap, matches);
+    int wsddService::ResolveMatches(struct wsdd__ResolveMatchesType *matches)
+    {
+      return __wsdd__ResolveMatches(this->soap, matches);
     }
 @endcode
 
+Note that soapcpp2 option `-a` may be needed to enable automatic service
+dispatching of WS-Addressing services based on the SOAP Action value instead of
+the SOAP/XML request operation.
+
 Another approach to generate the WSDD service operations is to run soapcpp2
 separately on wsdd.h (or wsdd5.h or wsdd10.h for WS-Discovery 1.0) by:
 
     soapcpp2 -a -L -pwsdd -Iimport import/wsdd.h
     
-to generate wsddService.cpp. Then chain the service operations at the server
-side:
+This generates wsddService.cpp and wsddClient.cpp, which should be compiled together with the rest of your project code. Then change wsddapi.h to use `#include "wsddH.h"`.
+
+Now with this approach you must chain the service operations at the server side
+as follows:
 
 @code
     if (soap_begin_serve(service.soap) == SOAP_OK)
       if (service.dispatch() == SOAP_NO_METHOD)
-	soap_serve_request(service.soap);
+        soap_serve_request(service.soap);
 @endcode
 
 where the `service` object is an instance of the application services generated
@@ -359,15 +375,22 @@ by soapcpp2 `-j`.
 
 @section wsdd_6 Miscellaneous
 
-You MUST generate client-side operations that the WSDD library expects to be
+You must generate client-side operations that the WSDD library expects to be
 linked with, by executing:
 
-    soapcpp2 -L -pwsdd -Iimport import/wsdd.h
+    soapcpp2 -a -L -pwsdd -Iimport import/wsdd.h
 
-Then compile and link the generated wsddClient.cpp code with your project.
+Then change wsddapi.h to use `#include "wsddH.h"` and compile and link the
+generated wsddClient.cpp code with your project.
 
-Because WS-Addressing may relay faults to a FaultTo service, you need to
-define a SOAP Fault service operation to accept and handle these:
+For server-side projects, also compile and link the generated wsddServer.cpp
+code.
+
+You will need to implement the @ref wsdd_2.
+
+Because WS-Addressing may relay faults to a FaultTo service, when implementing
+a service you will also have to define a SOAP Fault service operation to accept
+and handle these:
 
 @code
     int SOAP_ENV__Fault(struct soap *soap, char *faultcode, char *faultstring, char *faultactor, struct SOAP_ENV__Detail *detail, struct SOAP_ENV__Code *SOAP_ENV__Code, struct SOAP_ENV__Reason *SOAP_ENV__Reason, char *SOAP_ENV__Node, char *SOAP_ENV__Role, struct SOAP_ENV__Detail *SOAP_ENV__Detail)
@@ -385,6 +408,9 @@ define a SOAP Fault service operation to accept and handle these:
     }
 @endcode
 
+When implementing a WS-Discovery client and/or server without any other XML Web
+services, the above suffices to generate the required code.
+
 */
 
 #include "wsddapi.h"
@@ -399,7 +425,7 @@ const char *to_ts_URL = "urn:docs-oasis-open-org:ws-dd:ns:discovery:2009:01";
 
 /******************************************************************************\
  *
- *	WS-Discovery AppSequence State
+ *      WS-Discovery AppSequence State
  *
 \******************************************************************************/
 
@@ -422,7 +448,7 @@ static void soap_wsdd_delay(struct soap*);
 
 /******************************************************************************\
  *
- *	WS-Discovery Outbound Messages
+ *      WS-Discovery Outbound Messages
  *
 \******************************************************************************/
 
@@ -450,7 +476,9 @@ Hello is a one-way message sent by a Target Service to announce its
 availability when it joins the network. It is also sent by a Discovery Proxy to
 reduce multicast traffic on an ad hoc network.
 */
+SOAP_FMAC1
 int
+SOAP_FMAC2
 soap_wsdd_Hello(struct soap *soap, soap_wsdd_mode mode, const char *endpoint, const char *MessageID, const char *RelatesTo, const char *EndpointReference, const char *Types, const char *Scopes, const char *MatchBy, const char *XAddrs, unsigned int MetadataVersion)
 {
   struct wsdd__HelloType req;
@@ -498,6 +526,8 @@ soap_wsdd_Hello(struct soap *soap, soap_wsdd_mode mode, const char *endpoint, co
   return SOAP_OK;
 }
 
+/******************************************************************************/
+
 /**
 @fn int soap_wsdd_Bye(struct soap *soap, soap_wsdd_mode mode, const char *endpoint, const char *MessageID, const char *EndpointReference, const char *Types, const char *Scopes, const char *MatchBy, const char *XAddrs, unsigned int MetadataVersion)
 @brief TS or DP Bye message to leave a network.
@@ -516,7 +546,9 @@ soap_wsdd_Hello(struct soap *soap, soap_wsdd_mode mode, const char *endpoint, co
 Bye is a one-way message sent by a Target Service to announce its
 unavailability as a best effort when it leaves the network.
 */
+SOAP_FMAC1
 int
+SOAP_FMAC2
 soap_wsdd_Bye(struct soap *soap, soap_wsdd_mode mode, const char *endpoint, const char *MessageID, const char *EndpointReference, const char *Types, const char *Scopes, const char *MatchBy, const char *XAddrs, unsigned int MetadataVersion)
 {
   struct wsdd__ByeType req;
@@ -563,6 +595,8 @@ soap_wsdd_Bye(struct soap *soap, soap_wsdd_mode mode, const char *endpoint, cons
   return SOAP_OK;
 }
 
+/******************************************************************************/
+
 /**
 @fn int soap_wsdd_Probe(struct soap *soap, soap_wsdd_mode mode, soap_wsdd_to to, const char *endpoint, const char *MessageID, const char *ReplyTo, const char *Types, const char *Scopes, const char *MatchBy)
 @brief Client Probe message to a TS or DP.
@@ -583,7 +617,9 @@ Target Services. The matches will be delivered to @ref wsdd_event_ProbeMatches
 when @ref soap_wsdd_listen receives a ProbeMatch response. The RelatesTo of the
 ProbeMatches is the MessageID of the Probe.
 */
+SOAP_FMAC1
 int
+SOAP_FMAC2
 soap_wsdd_Probe(struct soap *soap, soap_wsdd_mode mode, soap_wsdd_to to, const char *endpoint, const char *MessageID, const char *ReplyTo, const char *Types, const char *Scopes, const char *MatchBy)
 {
   unsigned int InstanceId = 0;
@@ -658,6 +694,8 @@ soap_wsdd_Probe(struct soap *soap, soap_wsdd_mode mode, soap_wsdd_to to, const c
   return SOAP_OK;
 }
 
+/******************************************************************************/
+
 /**
 @fn int soap_wsdd_Resolve(struct soap *soap, soap_wsdd_mode mode, soap_wsdd_to to, const char *endpoint, const char *MessageID, const char *ReplyTo, const char *EndpointReference)
 @brief Client Resolve message to a TS or DP.
@@ -676,7 +714,9 @@ The matches will be delivered to @ref wsdd_event_ResolveMatches when @ref
 soap_wsdd_listen receives a ResolveMatch response. The RelatesTo of the
 ResolveMatches is the MessageID of the Resolve.
 */
+SOAP_FMAC1
 int
+SOAP_FMAC2
 soap_wsdd_Resolve(struct soap *soap, soap_wsdd_mode mode, soap_wsdd_to to, const char *endpoint, const char *MessageID, const char *ReplyTo, const char *EndpointReference)
 {
   unsigned int InstanceId = 0;
@@ -748,17 +788,24 @@ soap_wsdd_Resolve(struct soap *soap, soap_wsdd_mode mode, soap_wsdd_to to, const
   return SOAP_OK;
 }
 
+/******************************************************************************/
+
 /**
 @fn void soap_wsdd_init_ProbeMatches(struct soap *soap, struct wsdd__ProbeMatchesType *matches)
 @brief Initalize the probe matches container.
 @param soap context
 @param matches the container with matches to initialize
 */
+SOAP_FMAC1
 void
+SOAP_FMAC2
 soap_wsdd_init_ProbeMatches(struct soap *soap, struct wsdd__ProbeMatchesType *matches)
-{ soap_default_wsdd__ProbeMatchesType(soap, matches);
+{
+  soap_default_wsdd__ProbeMatchesType(soap, matches);
 }
 
+/******************************************************************************/
+
 /**
 @fn int soap_wsdd_add_ProbeMatch(struct soap *soap, struct wsdd__ProbeMatchesType *matches, const char *EndpointReference, const char *Types, const char *Scopes, const char *MatchBy, const char *XAddrs, unsigned int MetadataVersion)
 @brief Add a match to the probe matches container.
@@ -777,7 +824,9 @@ soap_wsdd_init_ProbeMatches, then use this function to add each match. The
 container is deallocated with soap_end(soap) and can be initialized again
 (without leaks).
 */
+SOAP_FMAC1
 int
+SOAP_FMAC2
 soap_wsdd_add_ProbeMatch(struct soap *soap, struct wsdd__ProbeMatchesType *matches, const char *EndpointReference, const char *Types, const char *Scopes, const char *MatchBy, const char *XAddrs, unsigned int MetadataVersion)
 {
   int n = 0, k = matches->__sizeProbeMatch;
@@ -823,6 +872,8 @@ soap_wsdd_add_ProbeMatch(struct soap *soap, struct wsdd__ProbeMatchesType *match
   return SOAP_OK;
 }
 
+/******************************************************************************/
+
 /**
 @fn int soap_wsdd_ProbeMatches(struct soap *soap, const char *endpoint, const char *MessageID, const char *RelatesTo, const char *To, struct wsdd__ProbeMatchesType *matches)
 @brief TS or DP ProbeMatches message.
@@ -839,7 +890,9 @@ Service, a Scope in which the Target Service resides, both, or simply all
 Target Services. The Target Server(s) or Discovery Proxy responds by sending
 ProbeMatches to the Client.
 */
+SOAP_FMAC1
 int
+SOAP_FMAC2
 soap_wsdd_ProbeMatches(struct soap *soap, const char *endpoint, const char *MessageID, const char *RelatesTo, const char *To, struct wsdd__ProbeMatchesType *matches)
 {
   const char *Action = SOAP_NAMESPACE_OF_wsdd"/ProbeMatches";
@@ -862,6 +915,8 @@ soap_wsdd_ProbeMatches(struct soap *soap, const char *endpoint, const char *Mess
   return SOAP_OK;
 }
 
+/******************************************************************************/
+
 /**
 @fn int soap_wsdd_ResolveMatches(struct soap *soap, const char *endpoint, const char *MessageID, const char *RelatesTo, const char *To, const char *EndpointReference, const char *Types, const char *Scopes, const char *MatchBy, const char *XAddrs, unsigned int MetadataVersion)
 @brief TS or DP ResolveMatches message.
@@ -882,7 +937,9 @@ A Client sends a resolve to locate a Target Service, i.e., to retrieve its
 transport address(es). The Target Server(s) or Discovery Proxy responds by
 sending ResolveMatches to the Client.
 */
+SOAP_FMAC1
 int
+SOAP_FMAC2
 soap_wsdd_ResolveMatches(struct soap *soap, const char *endpoint, const char *MessageID, const char *RelatesTo, const char *To, const char *EndpointReference, const char *Types, const char *Scopes, const char *MatchBy, const char *XAddrs, unsigned int MetadataVersion)
 {
   struct wsdd__ResolveMatchesType res;
@@ -928,13 +985,13 @@ soap_wsdd_ResolveMatches(struct soap *soap, const char *endpoint, const char *Me
 
 /******************************************************************************\
  *
- *	WS-Discovery Serving Inbound Messages
+ *      WS-Discovery Serving Inbound Messages
  *
 \******************************************************************************/
 
 /**
 @fn int soap_wsdd_listen(struct soap *soap, int timeout)
-@brief Listen on a port for inbound WS-Discovery messages.
+@brief Listen on a port for inbound WS-Discovery messages, also cleans up memory with `soap_destroy` and `soap_end`.
 @param soap context
 @param[in] timeout seconds to listen (use negative value for micro seconds)
 @return SOAP_OK or error code
@@ -946,7 +1003,9 @@ Use soap->user to pass a pointer to a state object that the event hanlders can
 use. The timeout allows a Client to periodically poll the port for messages. A
 value of zero will loop the listener forever or until an error occurs.
 */
+SOAP_FMAC1
 int
+SOAP_FMAC2
 soap_wsdd_listen(struct soap *soap, int timeout)
 {
   soap->accept_timeout = soap->recv_timeout = soap->send_timeout = timeout;
@@ -954,15 +1013,14 @@ soap_wsdd_listen(struct soap *soap, int timeout)
   /* event-serve loop (exits upon timeout) */
   for (;;)
   {
-    if (!soap_valid_socket(soap_accept(soap)))
+    if (!soap_valid_socket(soap_accept(soap))
+     || soap_begin_serve(soap))
     {
       /* timeout? */
       if (!soap->errnum)
-        return soap->error = SOAP_OK;
+        break;
       return soap->error;
     }
-    if (soap_begin_serve(soap))
-      return soap->error;
 
     /* always close HTTP afterwards */
     soap->keep_alive = 0;
@@ -972,7 +1030,7 @@ soap_wsdd_listen(struct soap *soap, int timeout)
     {
       /* timeout? */
       if (!soap->errnum)
-        return soap->error = SOAP_OK;
+	break;
 #ifdef WITH_FASTCGI
       soap_send_fault(soap);
 #else
@@ -983,9 +1041,18 @@ soap_wsdd_listen(struct soap *soap, int timeout)
     soap_destroy(soap);
     soap_end(soap);
   } 
+
+  /* timed out */
+  soap_destroy(soap);
+  soap_end(soap);
+  return soap->error = SOAP_OK;
 }
 
+/******************************************************************************/
+
+SOAP_FMAC1
 int
+SOAP_FMAC2
 soap_wsdd_serve_request(struct soap *soap)
 {
   soap_peek_element(soap);
@@ -1006,117 +1073,141 @@ soap_wsdd_serve_request(struct soap *soap)
   return soap_closesock(soap);
 }
 
+/******************************************************************************/
+
 #ifdef __cplusplus
 }
 #endif
 
+/******************************************************************************/
+
 static int
 soap_wsdd_serve___wsdd__Hello(struct soap *soap)
-{	struct __wsdd__Hello soap_tmp___wsdd__Hello;
-	soap_default___wsdd__Hello(soap, &soap_tmp___wsdd__Hello);
-	soap->encodingStyle = NULL;
-	if (!soap_get___wsdd__Hello(soap, &soap_tmp___wsdd__Hello, "-wsdd:Hello", NULL))
-		return soap->error;
-	if (soap_body_end_in(soap)
-	 || soap_envelope_end_in(soap)
-	 || soap_end_recv(soap))
-		return soap->error;
-	soap->error = __wsdd__Hello(soap, soap_tmp___wsdd__Hello.wsdd__Hello);
-	if (soap->error)
-		return soap->error;
-	return soap_closesock(soap);
+{
+  struct __wsdd__Hello soap_tmp___wsdd__Hello;
+  soap_default___wsdd__Hello(soap, &soap_tmp___wsdd__Hello);
+  soap->encodingStyle = NULL;
+  if (!soap_get___wsdd__Hello(soap, &soap_tmp___wsdd__Hello, "-wsdd:Hello", NULL))
+    return soap->error;
+  if (soap_body_end_in(soap)
+   || soap_envelope_end_in(soap)
+   || soap_end_recv(soap))
+    return soap->error;
+  soap->error = __wsdd__Hello(soap, soap_tmp___wsdd__Hello.wsdd__Hello);
+  if (soap->error)
+    return soap->error;
+  return soap_closesock(soap);
 }
 
+/******************************************************************************/
+
 static int
 soap_wsdd_serve___wsdd__Bye(struct soap *soap)
-{	struct __wsdd__Bye soap_tmp___wsdd__Bye;
-	soap_default___wsdd__Bye(soap, &soap_tmp___wsdd__Bye);
-	soap->encodingStyle = NULL;
-	if (!soap_get___wsdd__Bye(soap, &soap_tmp___wsdd__Bye, "-wsdd:Bye", NULL))
-		return soap->error;
-	if (soap_body_end_in(soap)
-	 || soap_envelope_end_in(soap)
-	 || soap_end_recv(soap))
-		return soap->error;
-	soap->error = __wsdd__Bye(soap, soap_tmp___wsdd__Bye.wsdd__Bye);
-	if (soap->error)
-		return soap->error;
-	return soap_closesock(soap);
+{
+  struct __wsdd__Bye soap_tmp___wsdd__Bye;
+  soap_default___wsdd__Bye(soap, &soap_tmp___wsdd__Bye);
+  soap->encodingStyle = NULL;
+  if (!soap_get___wsdd__Bye(soap, &soap_tmp___wsdd__Bye, "-wsdd:Bye", NULL))
+    return soap->error;
+  if (soap_body_end_in(soap)
+   || soap_envelope_end_in(soap)
+   || soap_end_recv(soap))
+    return soap->error;
+  soap->error = __wsdd__Bye(soap, soap_tmp___wsdd__Bye.wsdd__Bye);
+  if (soap->error)
+    return soap->error;
+  return soap_closesock(soap);
 }
 
+/******************************************************************************/
+
 static int
 soap_wsdd_serve___wsdd__Probe(struct soap *soap)
-{	struct __wsdd__Probe soap_tmp___wsdd__Probe;
-	soap_default___wsdd__Probe(soap, &soap_tmp___wsdd__Probe);
-	soap->encodingStyle = NULL;
-	if (!soap_get___wsdd__Probe(soap, &soap_tmp___wsdd__Probe, "-wsdd:Probe", NULL))
-		return soap->error;
-	if (soap_body_end_in(soap)
-	 || soap_envelope_end_in(soap)
-	 || soap_end_recv(soap))
-		return soap->error;
-	soap->error = __wsdd__Probe(soap, soap_tmp___wsdd__Probe.wsdd__Probe);
-	if (soap->error)
-		return soap->error;
-	return soap_closesock(soap);
+{
+  struct __wsdd__Probe soap_tmp___wsdd__Probe;
+  soap_default___wsdd__Probe(soap, &soap_tmp___wsdd__Probe);
+  soap->encodingStyle = NULL;
+  if (!soap_get___wsdd__Probe(soap, &soap_tmp___wsdd__Probe, "-wsdd:Probe", NULL))
+    return soap->error;
+  if (soap_body_end_in(soap)
+   || soap_envelope_end_in(soap)
+   || soap_end_recv(soap))
+    return soap->error;
+  soap->error = __wsdd__Probe(soap, soap_tmp___wsdd__Probe.wsdd__Probe);
+  if (soap->error)
+    return soap->error;
+  return soap_closesock(soap);
 }
 
+/******************************************************************************/
+
 static int
 soap_wsdd_serve___wsdd__ProbeMatches(struct soap *soap)
-{	struct __wsdd__ProbeMatches soap_tmp___wsdd__ProbeMatches;
-	soap_default___wsdd__ProbeMatches(soap, &soap_tmp___wsdd__ProbeMatches);
-	soap->encodingStyle = NULL;
-	if (!soap_get___wsdd__ProbeMatches(soap, &soap_tmp___wsdd__ProbeMatches, "-wsdd:ProbeMatches", NULL))
-		return soap->error;
-	if (soap_body_end_in(soap)
-	 || soap_envelope_end_in(soap)
-	 || soap_end_recv(soap))
-		return soap->error;
-	soap->error = __wsdd__ProbeMatches(soap, soap_tmp___wsdd__ProbeMatches.wsdd__ProbeMatches);
-	if (soap->error)
-		return soap->error;
-	return soap_closesock(soap);
+{
+  struct __wsdd__ProbeMatches soap_tmp___wsdd__ProbeMatches;
+  soap_default___wsdd__ProbeMatches(soap, &soap_tmp___wsdd__ProbeMatches);
+  soap->encodingStyle = NULL;
+  if (!soap_get___wsdd__ProbeMatches(soap, &soap_tmp___wsdd__ProbeMatches, "-wsdd:ProbeMatches", NULL))
+    return soap->error;
+  if (soap_body_end_in(soap)
+   || soap_envelope_end_in(soap)
+   || soap_end_recv(soap))
+    return soap->error;
+  soap->error = __wsdd__ProbeMatches(soap, soap_tmp___wsdd__ProbeMatches.wsdd__ProbeMatches);
+  if (soap->error)
+    return soap->error;
+  return soap_closesock(soap);
 }
 
+/******************************************************************************/
+
 static int
 soap_wsdd_serve___wsdd__Resolve(struct soap *soap)
-{	struct __wsdd__Resolve soap_tmp___wsdd__Resolve;
-	soap_default___wsdd__Resolve(soap, &soap_tmp___wsdd__Resolve);
-	soap->encodingStyle = NULL;
-	if (!soap_get___wsdd__Resolve(soap, &soap_tmp___wsdd__Resolve, "-wsdd:Resolve", NULL))
-		return soap->error;
-	if (soap_body_end_in(soap)
-	 || soap_envelope_end_in(soap)
-	 || soap_end_recv(soap))
-		return soap->error;
-	soap->error = __wsdd__Resolve(soap, soap_tmp___wsdd__Resolve.wsdd__Resolve);
-	if (soap->error)
-		return soap->error;
-	return soap_closesock(soap);
+{
+  struct __wsdd__Resolve soap_tmp___wsdd__Resolve;
+  soap_default___wsdd__Resolve(soap, &soap_tmp___wsdd__Resolve);
+  soap->encodingStyle = NULL;
+  if (!soap_get___wsdd__Resolve(soap, &soap_tmp___wsdd__Resolve, "-wsdd:Resolve", NULL))
+    return soap->error;
+  if (soap_body_end_in(soap)
+   || soap_envelope_end_in(soap)
+   || soap_end_recv(soap))
+    return soap->error;
+  soap->error = __wsdd__Resolve(soap, soap_tmp___wsdd__Resolve.wsdd__Resolve);
+  if (soap->error)
+    return soap->error;
+  return soap_closesock(soap);
 }
 
+/******************************************************************************/
+
 static int
 soap_wsdd_serve___wsdd__ResolveMatches(struct soap *soap)
-{	struct __wsdd__ResolveMatches soap_tmp___wsdd__ResolveMatches;
-	soap_default___wsdd__ResolveMatches(soap, &soap_tmp___wsdd__ResolveMatches);
-	soap->encodingStyle = NULL;
-	if (!soap_get___wsdd__ResolveMatches(soap, &soap_tmp___wsdd__ResolveMatches, "-wsdd:ResolveMatches", NULL))
-		return soap->error;
-	if (soap_body_end_in(soap)
-	 || soap_envelope_end_in(soap)
-	 || soap_end_recv(soap))
-		return soap->error;
-	soap->error = __wsdd__ResolveMatches(soap, soap_tmp___wsdd__ResolveMatches.wsdd__ResolveMatches);
-	if (soap->error)
-		return soap->error;
-	return soap_closesock(soap);
+{
+  struct __wsdd__ResolveMatches soap_tmp___wsdd__ResolveMatches;
+  soap_default___wsdd__ResolveMatches(soap, &soap_tmp___wsdd__ResolveMatches);
+  soap->encodingStyle = NULL;
+  if (!soap_get___wsdd__ResolveMatches(soap, &soap_tmp___wsdd__ResolveMatches, "-wsdd:ResolveMatches", NULL))
+    return soap->error;
+  if (soap_body_end_in(soap)
+   || soap_envelope_end_in(soap)
+   || soap_end_recv(soap))
+    return soap->error;
+  soap->error = __wsdd__ResolveMatches(soap, soap_tmp___wsdd__ResolveMatches.wsdd__ResolveMatches);
+  if (soap->error)
+    return soap->error;
+  return soap_closesock(soap);
 }
 
+/******************************************************************************/
+
 /**
 @fn int __wsdd__Hello(struct soap *soap, struct wsdd__HelloType *Hello)
 @brief Internal WS-Discovery service operation.
 */
+SOAP_FMAC5
 int
+SOAP_FMAC6
 __wsdd__Hello(struct soap *soap, struct wsdd__HelloType *Hello)
 {
   unsigned int InstanceId = 0;
@@ -1180,11 +1271,15 @@ __wsdd__Hello(struct soap *soap, struct wsdd__HelloType *Hello)
   return SOAP_OK;
 }
 
+/******************************************************************************/
+
 /**
 @fn int __wsdd__Bye(struct soap *soap, struct wsdd__ByeType *Bye)
 @brief Internal WS-Discovery service operation.
 */
+SOAP_FMAC5
 int
+SOAP_FMAC6
 __wsdd__Bye(struct soap *soap, struct wsdd__ByeType *Bye)
 {
   unsigned int InstanceId = 0;
@@ -1248,18 +1343,24 @@ __wsdd__Bye(struct soap *soap, struct wsdd__ByeType *Bye)
   return SOAP_OK;
 }
 
+/******************************************************************************/
+
 static int
-soap_wsdd_http(struct soap *soap, const char *endpoint, const char *host, int port, const char *path, const char *action, size_t count)
+soap_wsdd_http(struct soap *soap, const char *endpoint, const char *host, int port, const char *path, const char *action, ULONG64 count)
 {
   (void)endpoint; (void)host; (void)port; (void)path; (void)action;
   return soap->fresponse(soap, SOAP_OK, count);
 }
 
+/******************************************************************************/
+
 /**
 @fn int __wsdd__Probe(struct soap *soap, struct wsdd__ProbeType *Probe)
 @brief Internal WS-Discovery service operation.
 */
+SOAP_FMAC5
 int
+SOAP_FMAC6
 __wsdd__Probe(struct soap *soap, struct wsdd__ProbeType *Probe)
 {
   struct wsdd__ProbeMatchesType ProbeMatches;
@@ -1302,7 +1403,7 @@ __wsdd__Probe(struct soap *soap, struct wsdd__ProbeType *Probe)
   else
   {
     int err;
-    int (*fpost)(struct soap*, const char*, const char*, int, const char*, const char*, size_t);
+    int (*fpost)(struct soap*, const char*, const char*, int, const char*, const char*, ULONG64);
     const char *MessageID = soap_wsa_rand_uuid(soap);
     const char *Action = SOAP_NAMESPACE_OF_wsdd"/ProbeMatches";
 
@@ -1320,11 +1421,15 @@ __wsdd__Probe(struct soap *soap, struct wsdd__ProbeType *Probe)
   return SOAP_OK;
 }
 
+/******************************************************************************/
+
 /**
 @fn int __wsdd__ProbeMatches(struct soap *soap, struct wsdd__ProbeMatchesType *ProbeMatches)
 @brief Internal WS-Discovery service operation.
 */
+SOAP_FMAC5
 int
+SOAP_FMAC6
 __wsdd__ProbeMatches(struct soap *soap, struct wsdd__ProbeMatchesType *ProbeMatches)
 {
   unsigned int InstanceId = 0;
@@ -1370,11 +1475,15 @@ __wsdd__ProbeMatches(struct soap *soap, struct wsdd__ProbeMatchesType *ProbeMatc
   return SOAP_OK;
 }
 
+/******************************************************************************/
+
 /**
 @fn int __wsdd__Resolve(struct soap *soap, struct wsdd__ResolveType *Resolve)
 @brief Internal WS-Discovery service operation.
 */
+SOAP_FMAC5
 int
+SOAP_FMAC6
 __wsdd__Resolve(struct soap *soap, struct wsdd__ResolveType *Resolve)
 {
   struct wsdd__ResolveMatchesType ResolveMatches;
@@ -1425,7 +1534,7 @@ __wsdd__Resolve(struct soap *soap, struct wsdd__ResolveType *Resolve)
   else
   {
     int err;
-    int (*fpost)(struct soap*, const char*, const char*, int, const char*, const char*, size_t);
+    int (*fpost)(struct soap*, const char*, const char*, int, const char*, const char*, ULONG64);
     const char *MessageID = soap_wsa_rand_uuid(soap);
     const char *Action = SOAP_NAMESPACE_OF_wsdd"/ResolveMatches";
 
@@ -1443,11 +1552,15 @@ __wsdd__Resolve(struct soap *soap, struct wsdd__ResolveType *Resolve)
   return SOAP_OK;
 }
 
+/******************************************************************************/
+
 /**
 @fn int __wsdd__ResolveMatches(struct soap *soap, struct wsdd__ResolveMatchesType *ResolveMatches)
 @brief Internal WS-Discovery service operation.
 */
+SOAP_FMAC5
 int
+SOAP_FMAC6
 __wsdd__ResolveMatches(struct soap *soap, struct wsdd__ResolveMatchesType *ResolveMatches)
 {
   unsigned int InstanceId = 0;
@@ -1496,7 +1609,7 @@ __wsdd__ResolveMatches(struct soap *soap, struct wsdd__ResolveMatchesType *Resol
 
 /******************************************************************************\
  *
- *	WS-Discovery AppSequence State
+ *      WS-Discovery AppSequence State
  *
 \******************************************************************************/
 
@@ -1509,7 +1622,9 @@ extern "C" {
 @brief Set the global AppSequence InstanceId that is used to populate messages
 @param[in] InstanceId
 */
+SOAP_FMAC1
 void
+SOAP_FMAC2
 soap_wsdd_set_InstanceId(unsigned int InstanceId)
 {
   MUTEX_LOCK(soap_wsdd_state);
@@ -1518,12 +1633,16 @@ soap_wsdd_set_InstanceId(unsigned int InstanceId)
   MUTEX_UNLOCK(soap_wsdd_state);
 }
 
+/******************************************************************************/
+
 /**
 @fn void soap_wsdd_set_SequenceId(const char *SequenceId)
 @brief Set the global AppSequence SequenceId that is used to populate messages
 @param[in] SequenceId
 */
+SOAP_FMAC1
 void
+SOAP_FMAC2
 soap_wsdd_set_SequenceId(const char *SequenceId)
 {
   MUTEX_LOCK(soap_wsdd_state);
@@ -1534,10 +1653,14 @@ soap_wsdd_set_SequenceId(const char *SequenceId)
   MUTEX_UNLOCK(soap_wsdd_state);
 }
 
+/******************************************************************************/
+
 #ifdef __cplusplus
 }
 #endif
 
+/******************************************************************************/
+
 static void
 soap_wsdd_set_AppSequence(struct soap *soap)
 {
@@ -1555,6 +1678,8 @@ soap_wsdd_set_AppSequence(struct soap *soap)
   MUTEX_UNLOCK(soap_wsdd_state);
 }
 
+/******************************************************************************/
+
 static void
 soap_wsdd_reset_AppSequence(struct soap *soap)
 {
@@ -1562,10 +1687,23 @@ soap_wsdd_reset_AppSequence(struct soap *soap)
     soap->header->wsdd__AppSequence = NULL;
 }
 
+/******************************************************************************/
+
 static void
 soap_wsdd_delay(struct soap *soap)
 {
-  (void)soap;
-  useconds_t delay = 1000*((unsigned int)soap_random % SOAP_WSDD_APP_MAX_DELAY);
+  unsigned int r = (unsigned int)soap_random % SOAP_WSDD_APP_MAX_DELAY;
+#if defined(_WRS_KERNEL)
+  int delay = r * sysClkRateGet() / 1000;
+  taskDelay(delay); /* VxWorks compatible sleep API, delay is specified in number of ticks, which depends on the System Clock Rate */
+#elif defined(WIN32)
+  DWORD delay = (DWORD)r;
+  Sleep(delay);
+#else
+  useconds_t delay = 1000 * r;
   usleep(delay);
+#endif
+  (void)soap;
 }
+
+/******************************************************************************/
