@@ -195,13 +195,14 @@ NULL, `password` to authenticate or NULL, `saml1` if non-NULL, requests SAML
 received, `saml2` if non-NULL, requests SAML 2.0 and upon return points to a
 pointer that is set to the SAML 2.0 assertion received.
 
-Returns `SOAP_OK` on success with `saml1` or `saml2` set and verified.
+Returns `SOAP_OK` on success when the assertion could be verified, with `saml1`
+or `saml2` set.
 
 For example:
 
 @code
-    #include "wsaapi.h"
     #include "wstapi.h"
+    #include "wsaapi.h"
     #include "wsseapi.h"
     #include "wst.nsmap"
 
@@ -243,7 +244,7 @@ For example:
         {
           if (saml2->__union_AssertionType[i].saml2__Statement)
           {
-            // left out
+            // omitted from displaying
           }
           if (saml2->__union_AssertionType[i].saml2__AuthnStatement)
           {
@@ -255,7 +256,7 @@ For example:
           }
           if (saml2->__union_AssertionType[i].saml2__AuthzDecisionStatement)
           {
-            // left out
+            // omitted from displaying
           }
           if (saml2->__union_AssertionType[i].saml2__AttributeStatement)
           {
@@ -290,6 +291,18 @@ For example:
     soap_free(soap);
 @endcode
 
+This prints several of the assertion's properties, including the conditions
+under which the assertion is valid.  The `NotBefore` and `NotOnOrAfter`
+conditions can be checked against the current time as follows:
+
+@code
+    time_t now = time(NULL);
+    if (saml2->saml2__Conditions->NotBefore && *saml2->saml2__Conditions->NotBefore > now)
+      ... error // not valid yet
+    if (saml2->saml2__Conditions->NotOnOrAfter && *saml2->saml2__Conditions->NotOnOrAfter <= now)
+      ... error // expired
+@endcode
+
 @subsection wst_soap_wst_request_psha1_token
 
 @code
@@ -343,10 +356,53 @@ Returns `SOAP_OK` on success.
     soap_free(soap);
 @endcode
 
+@section wst_5 Using the wst Plugin for Servers
+
+To implement a WS-Trust server in C, run soapcpp2 as follows:
+
+    soapcpp2 -c -L file.h
+
+where file.h has an `#import "wst.h"`.  This generates the soapServer.c and soapC.c code you need to compile with wstapi.c, wsaapi.c, wsseapi.c, smdevp.c, and mecevp.c.  Link with libgsoapssl.a (or stdsoap2.c and dom.c).  Use `-DWITH_OPENSSL` and `-DWITH_DOM` to compile the source code.
+
+For C++, use:
+
+    soapcpp2 -L file.h
+
+This generates the soapServer.cpp and soapC.cpp code you need to compile with wstapi.c, wsaapi.c, wsseapi.c, smdevp.c, and mecevp.c.  Link with libgsoapssl++.a (or stdsoap2.cpp and dom.cpp).  Use `-DWITH_OPENSSL` and `-DWITH_DOM` to compile the source code.
+
+If you prefer to use soapcpp2 option `-j` (or `-i`) to generate C++ server objects, please run soacpp2 again as follows:
+
+    soapcpp2 -j -L file.h
+    soapcpp2 -CL -pwst import/wst.h
+
+This generates wstClient.cpp, which should be compiled together with the rest of your project code.
+
+You should define the following service operations:
+
+@code
+    int wstService::RequestSecurityToken(wst__RequestSecurityTokenType *request, wst__RequestSecurityTokenResponseType *response)
+    {
+      ...
+    }
+    int wstService::RequestSecurityTokenCollection(struct wst__RequestSecurityTokenCollectionType *request, struct wst__RequestSecurityTokenResponseCollectionType *response)
+    {
+      ...
+    }
+@endcode
+
+If you are combinding WS-Trust with other service operations, then you must also chain the service operations at the server side as follows:
+
+@code
+    if (soap_begin_serve(service.soap) == SOAP_OK)
+      if (service.dispatch() == SOAP_NO_METHOD)
+        soap_serve_request(service.soap);
+@endcode
+
+where the `service` object is an instance of the application services generated by soapcpp2 `-j`.
+
 */
 
 #include "wstapi.h"
-#include "wsseapi.h"
 
 const char *soap_wst_rst_action = SOAP_NAMESPACE_OF_wst "/RST/Issue";
 const char *soap_wst_rstr_action = SOAP_NAMESPACE_OF_wst "/RSTR/Issue";
@@ -407,7 +463,7 @@ extern "C" {
 
 /**
 @fn int soap_wst_request_saml_token(struct soap *soap, const char *endpoint, int soapver, const char *applyto, const char *username, const char *password, saml1__AssertionType **saml1, saml2__AssertionType **saml2)
-@brief Request SAML 1.0 or SAML 2.0 token.
+@brief Request SAML 1.0 or SAML 2.0 token.  Verifies the SAML signature, which requires soap->cafile to be set.   Does not verify the conditions of the SAML token, such as NotBefore and NotOnOrAfter, which has to be done explicitly as shown in the documentation.
 @param soap context
 @param endpoint service endpoint URL (send to)
 @param soapver SOAP version 1 = SOAP 1.1, 2 = SOAP 1.2 (recommended)
@@ -477,11 +533,18 @@ soap_wst_request_saml_token(struct soap *soap, const char *endpoint, int soapver
     else if (saml2 && !strcmp(response.TokenType, "urn:oasis:names:tc:SAML:2.0:assertion"))
       *saml2 = response.RequestedSecurityToken->saml2__Assertion;
   }
-  /* verify assertion using the enveloped signature that contains a X509 certificate */
-  if (saml1 && *saml1 && soap_wsse_verify_with_signature(soap, (*saml1)->ds__Signature))
-    return soap->error;
-  if (saml2 && *saml2 && soap_wsse_verify_with_signature(soap, (*saml2)->ds__Signature))
-    return soap->error;
+  if (saml1 && *saml1)
+  {
+    /* verify assertion using the enveloped signature that contains a X509 certificate */
+    if (soap_wsse_verify_with_signature(soap, (*saml1)->ds__Signature))
+      return soap->error;
+  }
+  else if (saml2 && *saml2)
+  {
+    /* verify assertion using the enveloped signature that contains a X509 certificate */
+    if (soap_wsse_verify_with_signature(soap, (*saml2)->ds__Signature))
+      return soap->error;
+  }
   return SOAP_OK;
 }
 
