@@ -177,13 +177,13 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
 --------------------------------------------------------------------------------
 */
 
-#include "soapH.h"                      // generated by soapcpp2 -CSL dom.h
+#include "soapH.h"              // generated by soapcpp2 -CSL import/dom.h
 #include <fstream>
 #include <sstream>
 #include <iomanip>
 #include <map>
 
-#define DOM_ROOT "root"			// unnamed root element is named "root"
+#define DOM_ROOT "root"         // unnamed root element is named "root"
 
 struct Namespace namespaces[] = {{NULL,NULL,NULL,NULL}};
 
@@ -453,7 +453,7 @@ int main(int argc, char **argv)
       ifs.open(ifile, std::ifstream::in);
       if (!ifs.is_open())
       {
-        fprintf(stderr, "Cannot open %s for reading\n", ifile);
+        fprintf(stderr, "domcpp: Cannot open %s for reading\n", ifile);
         exit(EXIT_FAILURE);
       }
       ctx->is = &ifs;
@@ -467,7 +467,7 @@ int main(int argc, char **argv)
     ofs.open(ofile, std::ofstream::out);
     if (!ofs.is_open())
     {
-      fprintf(stderr, "Cannot open %s for writing\n", ofile);
+      fprintf(stderr, "domcpp: Cannot open %s for writing\n", ofile);
       exit(EXIT_FAILURE);
     }
     ctx->os = &ofs;
@@ -489,7 +489,7 @@ int main(int argc, char **argv)
     }
     if (!dom.tag())
     {
-      fprintf(stderr, "No root element in %s\n", ifile);
+      fprintf(stderr, "domcpp: No root element in %s\n", ifile);
       exit(EXIT_FAILURE);
     }
   }
@@ -548,11 +548,11 @@ int main(int argc, char **argv)
       "   file and generate the namespace table automatically.\n";
     if (nstable)
       *ctx->os <<
-	"\n"
-	"   The first four entries are required in this order for gSOAP client/server\n"
-	"   applications.  When combining this code with a gSOAP client/server\n"
-	"   application then use the soapcpp2-generated .nsmap file with namespace table\n"
-	"   for that application and add entries below that are missing from the table.\n";
+        "\n"
+        "   The first four entries are required in this order for gSOAP client/server\n"
+        "   applications.  When combining this code with a gSOAP client/server\n"
+        "   application then use the soapcpp2-generated .nsmap file with namespace table\n"
+        "   for that application and add entries below that are missing from the table.\n";
     *ctx->os << "*/\n";
   }
 
@@ -619,12 +619,12 @@ int main(int argc, char **argv)
       *ctx->os << " " << putstr(argv[i], 0);
     if (coutput)
       *ctx->os <<
-	" */\n"
-	"  /* domcpp tool Copyright (C) 2000-2016, Robert van Engelen, Genivia Inc. */\n";
+        " */\n"
+        "  /* domcpp tool Copyright (C) 2000-2016, Robert van Engelen, Genivia Inc. */\n";
     else
       *ctx->os <<
-	"\n"
-	"  // domcpp tool Copyright (C) 2000-2016, Robert van Engelen, Genivia Inc.\n";
+        "\n"
+        "  // domcpp tool Copyright (C) 2000-2016, Robert van Engelen, Genivia Inc.\n";
     *ctx->os <<
       "  struct soap *ctx = soap_new1(SOAP_C_UTFSTRING | SOAP_XML_INDENT | SOAP_DOM_TREE);\n"
       "  ctx->double_format = \"" << (dform ? dform : "%lG") << "\";\n\n";
@@ -803,7 +803,6 @@ int main(int argc, char **argv)
           "  if (" << xroot << ".soap->error)\n"
           "    exit(EXIT_FAILURE); // error parsing XML\n";
 
-
       if (ifile)
       {
         if (explain)
