@@ -13,7 +13,7 @@ static struct CRYPTO_dynlock_value *dyn_create_function(const char *file, int li
 {
   struct CRYPTO_dynlock_value *value;
   (void)file; (void)line;
-  value = (struct CRYPTO_dynlock_value*)malloc(sizeof(struct CRYPTO_dynlock_value));
+  value = (struct CRYPTO_dynlock_value*)OPENSSL_malloc(sizeof(struct CRYPTO_dynlock_value));
   if (value)
     MUTEX_SETUP(value->mutex);
   return value;
@@ -32,7 +32,7 @@ static void dyn_destroy_function(struct CRYPTO_dynlock_value *l, const char *fil
 {
   (void)file; (void)line;
   MUTEX_CLEANUP(l->mutex);
-  free(l);
+  OPENSSL_free(l);
 }
 
 static void locking_function(int mode, int n, const char *file, int line)
@@ -52,7 +52,7 @@ static unsigned long id_function()
 int CRYPTO_thread_setup()
 {
   int i;
-  mutex_buf = (MUTEX_TYPE*)malloc(CRYPTO_num_locks() * sizeof(pthread_mutex_t));
+  mutex_buf = (MUTEX_TYPE*)OPENSSL_malloc(CRYPTO_num_locks() * sizeof(MUTEX_TYPE));
   if (!mutex_buf)
     return SOAP_EOM;
   for (i = 0; i < CRYPTO_num_locks(); i++)
@@ -77,7 +77,7 @@ void CRYPTO_thread_cleanup()
   CRYPTO_set_dynlock_destroy_callback(NULL);
   for (i = 0; i < CRYPTO_num_locks(); i++)
     MUTEX_CLEANUP(mutex_buf[i]);
-  free(mutex_buf);
+  OPENSSL_free(mutex_buf);
   mutex_buf = NULL;
 }
 
