@@ -6,7 +6,7 @@
 	Prints current time.
 
 	Compile:
-	soapcpp2 xml-rpc.h
+	soapcpp2 -CSL xml-rpc.h
 	c++ json-currentTime.cpp xml-rpc.cpp json.cpp stdsoap2.cpp soapC.cpp
 
 --------------------------------------------------------------------------------
