@@ -1,17 +1,17 @@
 /*
-	json-currentTimeServer.cpp
+        json-currentTimeServer.cpp
 
-	JSON currenTime server (C++ version)
-	CGI or stand-alone multi-threaded server
+        JSON currenTime server (C++ version)
+        CGI or stand-alone multi-threaded server
 
-	Returns JSON message with current time to client.
+        Returns JSON message with current time to client.
 
-	Compile:
-	soapcpp2 xml-rpc.h
-	c++ -o json-currentTimeServer json-currentTimeServer.cpp json.cpp xml-rpc.cpp stdsoap2.cpp soapC.cpp
-	Install as CGI on Web server
-	Or run as stand-alone server (e.g. on port 18000):
-	./json-currentTimeServer 18000
+        Compile:
+        soapcpp2 -CSL xml-rpc.h
+        c++ -o json-currentTimeServer json-currentTimeServer.cpp json.cpp xml-rpc.cpp stdsoap2.cpp soapC.cpp
+        Install as CGI on Web server
+        Or run as stand-alone server (e.g. on port 18000):
+        ./json-currentTimeServer 18000
 
 --------------------------------------------------------------------------------
 gSOAP XML Web services tools
@@ -43,13 +43,7 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
 
 #include "json.h"
 
-#include <unistd.h>
-#ifdef _POSIX_THREADS
-#include <pthread.h>    // use Pthreads
-#endif
-
-#define BACKLOG (100)	// Max. request backlog
-#define MAX_THR (8)	// Max. threads to serve requests
+#include "plugin/threads.h"
 
 using namespace std;
 
@@ -58,38 +52,68 @@ int serve_request(soap*);
 int main(int argc, char **argv)
 {
   soap *ctx = soap_new1(SOAP_C_UTFSTRING);
-  ctx->send_timeout = 10; // 10 sec
-  ctx->recv_timeout = 10; // 10 sec
 
   if (argc < 2)
-    return serve_request(ctx);
+  {
+    // process CGI request
+    value request(ctx);
+
+    if (soap_begin_recv(ctx)
+     || json_recv(ctx, request)
+     || soap_end_recv(ctx))
+    {
+      soap_send_fault(ctx);
+    }
+    else
+    {
+      value response(ctx);
+  
+      // if the name matches: set response to time, else error
+      if (request.is_string() && !strcmp(request, "getCurrentTime"))
+      {
+        response = (ULONG64)time(0);
+      }
+      else
+      {
+        response["fault"] = "Wrong method";
+        response["detail"] = request;
+      }
+
+      // set the http content type
+      ctx->http_content = "application/json; charset=utf-8";
+      // send the response
+      if (soap_begin_count(ctx)
+       || ((ctx->mode & SOAP_IO_LENGTH) && json_send(ctx, response))
+       || soap_end_count(ctx)
+       || soap_response(ctx, SOAP_FILE)
+       || json_send(ctx, response)
+       || soap_end_send(ctx))
+        soap_print_fault(ctx, stderr);
+    }
+    soap_destroy(ctx);
+    soap_end(ctx);
+    soap_free(ctx);
+    return 0;
+  }
 
   int port = atoi(argv[1]);
 
-#ifdef _POSIX_THREADS
-  pthread_t tid;
-#endif
-
-  if (!soap_valid_socket(soap_bind(ctx, NULL, port, BACKLOG)))
+  if (!soap_valid_socket(soap_bind(ctx, NULL, port, 100)))
   {
     soap_print_fault(ctx, stderr);
     exit(1);
   }
 
-  for (;;)
+  ctx->send_timeout = 10;
+  ctx->recv_timeout = 10;
+
+  while (1)
   {
+    THREAD_TYPE tid;
     if (!soap_valid_socket(soap_accept(ctx)))
-    {
       soap_print_fault(ctx, stderr);
-    }
     else
-    {
-#ifdef _POSIX_THREADS
-      pthread_create(&tid, NULL, (void*(*)(void*))serve_request, (void*)soap_copy(ctx));
-#else
-      serve_request(ctx);
-#endif
-    }
+      THREAD_CREATE(&tid, (void*(*)(void*))serve_request, (void*)soap_copy(ctx));
   }
   soap_destroy(ctx);
   soap_end(ctx);
@@ -100,21 +124,18 @@ int main(int argc, char **argv)
 
 int serve_request(soap* ctx)
 {
-#ifdef _POSIX_THREADS
-  pthread_detach(pthread_self());
-#endif
+  THREAD_DETACH(THREAD_ID);
 
-  value request(ctx);
-    
   // HTTP keep-alive max number of iterations
   unsigned int k = ctx->max_keep_alive;
+  value request(ctx);
 
   do
   {
     if (ctx->max_keep_alive > 0 && !--k)
       ctx->keep_alive = 0;
 
-    // receive HTTP header (optional) and JSON content
+    // receive JSON request
     if (soap_begin_recv(ctx)
      || json_recv(ctx, request)
      || soap_end_recv(ctx))
@@ -124,17 +145,16 @@ int serve_request(soap* ctx)
       value response(ctx);
   
       if (request.is_string() && !strcmp(request, "getCurrentTime"))
-        // method name matches: first parameter of response is time
+      {
         response = (ULONG64)time(0);
+      }
       else
-      { // otherwise, set fault
+      {
         response["fault"] = "Wrong method";
         response["detail"] = request;
       }
 
-      // http content type
       ctx->http_content = "application/json; charset=utf-8";
-      // http content length
       if (soap_begin_count(ctx)
        || ((ctx->mode & SOAP_IO_LENGTH) && json_send(ctx, response))
        || soap_end_count(ctx)
@@ -153,11 +173,7 @@ int serve_request(soap* ctx)
   // clean up
   soap_destroy(ctx);
   soap_end(ctx);
-
-#ifdef _POSIX_THREADS
-  // free the ctx copy for this thread
   soap_free(ctx);
-#endif
 
   return err;
 }
