@@ -2,16 +2,17 @@
 	xml-rpc-currentTime.c
 
 	XML-RPC currenTime (C version)
+	Updated for gSOAP 2.8.26 with new XML-RPC C API xml-rpc.c
 
 	Prints current time.
 
 	Compile:
-	soapcpp2 -c xml-rpc.h
-	cc xml-rpc-currentTime.c stdsoap2.c soapC.c
+	soapcpp2 -c -CSL xml-rpc.h
+	cc xml-rpc-currentTime.c xml-rpc.c stdsoap2.c soapC.c
 
 --------------------------------------------------------------------------------
 gSOAP XML Web services tools
-Copyright (C) 2001-2008, Robert van Engelen, Genivia, Inc. All Rights Reserved.
+Copyright (C) 2000-2015, Robert van Engelen, Genivia, Inc. All Rights Reserved.
 This software is released under one of the following two licenses:
 GPL or Genivia's license for commercial use.
 --------------------------------------------------------------------------------
@@ -39,60 +40,31 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
 
 #include "soapH.h"
 
-int methodCall(struct soap *soap, const char *URL, struct methodCall *m, struct methodResponse *r);
-
 int main()
-{ struct soap *soap = soap_new();
-  struct methodCall m;
+{
+  struct soap *soap = soap_new1(SOAP_C_UTFSTRING);
   struct methodResponse r;
-  /* Set up method call */
-  m.methodName = "currentTime.getCurrentTime";
-  /* no parameters */
-  m.params.__size = 0;
-  /* no namespaces */
-  soap->namespaces = NULL;
-  /* no SOAP encodingStyle */
-  soap->encodingStyle = NULL;
-  /* connect, send request, and receive response */
-  if (methodCall(soap, "http://www.cs.fsu.edu/~engelen/currentTime.cgi", &m, &r))
-  { soap_print_fault(soap, stderr);
+  /* connect, send request w/o parameters (NULL) and receive response */
+  if (call_method(soap, "http://www.cs.fsu.edu/~engelen/currentTime.cgi", "currentTime.getCurrentTime", NULL, &r))
+  {
+    soap_print_fault(soap, stderr);
     exit(soap->error);
   }
   if (r.fault)
-  { /* print fault on stdout */
-    soap_begin_send(soap);
-    soap_put_fault(soap, r.fault, "fault", NULL);
-    soap_end_send(soap);
+  {
+    soap_write_fault(soap, r.fault); /* print fault on stdout */
   }
   else if (r.params && r.params->__size == 1)
   { /* print response parameter */
-    if (r.params->param[0].value.__type == SOAP_TYPE__dateTime_DOTiso8601)
-      printf("Time = %s\n", (char*)r.params->param[0].value.ref);
+    if (nth_param(r.params, 0)->__type == SOAP_TYPE__dateTime_DOTiso8601)
+      printf("Time = %s\n", *dateTime_of(nth_param(r.params, 0)));
     else
       printf("Time not provided\n");
   }
   soap_end(soap);
-  soap_done(soap);
-  free(soap);
+  soap_free(soap);
   return 0;
 }
 
-int methodCall(struct soap *soap, const char *URL, struct methodCall *m, struct methodResponse *r)
-{ /* no namespaces */
-  soap->namespaces = NULL;
-  /* no SOAP encodingStyle */
-  soap->encodingStyle = NULL;
-  /* connect, send request, and receive response */
-  if (soap_connect(soap, URL, NULL)
-   || soap_put_methodCall(soap, m, "methodCall", NULL)
-   || soap_end_send(soap)
-   || soap_begin_recv(soap)
-   || !soap_get_methodResponse(soap, r, "methodResponse", NULL)
-   || soap_end_recv(soap))
-    return soap_closesock(soap); /* closes socket and returns soap->error */
-  soap_closesock(soap);
-  return SOAP_OK;
-}
-
 /* Don't need a namespace table. We put an empty one here to avoid link errors */
 struct Namespace namespaces[] = { {NULL, NULL} };
