@@ -55,18 +55,19 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
 
 static int size2k(int n);
 
-struct value *new_value(struct soap *soap)
+struct value * new_value(struct soap *soap)
 {
   return init_value(soap, (struct value*)soap_malloc(soap, sizeof(struct value)));
 }
 
-struct value *init_value(struct soap *soap, struct value *v)
+struct value * init_value(struct soap *soap, struct value *v)
 {
-  soap_default_value(soap, v);
+  if (v)
+    soap_default_value(soap, v);
   return v;
 }
 
-_boolean *bool_of(struct value *v)
+_boolean * bool_of(struct value *v)
 {
   if (v->__type != SOAP_TYPE__boolean)
     if ((v->ref = (void*)soap_malloc(v->soap, sizeof(_boolean))))
@@ -76,7 +77,7 @@ _boolean *bool_of(struct value *v)
   return (_boolean*)v->ref;
 }
 
-_int *int_of(struct value *v)
+_int * int_of(struct value *v)
 {
   _int r = 0;
   if (v->__type == SOAP_TYPE__boolean)
@@ -98,7 +99,7 @@ _int *int_of(struct value *v)
   return (_int*)v->ref;
 }
 
-_double *double_of(struct value *v)
+_double * double_of(struct value *v)
 {
   _double r = 0;
   if (v->__type == SOAP_TYPE__boolean)
@@ -120,7 +121,7 @@ _double *double_of(struct value *v)
   return (_double*)v->ref;
 }
 
-const char **string_of(struct value *v)
+const char ** string_of(struct value *v)
 {
   if (v->__type == SOAP_TYPE__string || v->__type == SOAP_TYPE__dateTime_DOTiso8601)
     return (const char**)&v->ref;
@@ -143,7 +144,7 @@ const char **string_of(struct value *v)
   return (const char**)&v->ref;
 }
 
-const char **dateTime_of(struct value *v)
+const char ** dateTime_of(struct value *v)
 {
   if (v->__type != SOAP_TYPE__dateTime_DOTiso8601)
     v->ref = (void*)"";
@@ -152,7 +153,7 @@ const char **dateTime_of(struct value *v)
   return (const char**)&v->ref;
 }
 
-struct _base64 *base64_of(struct value *v)
+struct _base64 * base64_of(struct value *v)
 {
   if (v->__type != SOAP_TYPE__base64)
     if ((v->ref = (void*)soap_malloc(v->soap, sizeof(struct _base64))))
@@ -162,7 +163,7 @@ struct _base64 *base64_of(struct value *v)
   return (struct _base64*)v->ref;
 }
 
-struct value *value_at(struct value *v, const char *s)
+struct value * value_at(struct value *v, const char *s)
 {
   int i = 0;
   struct _struct *_struct = (struct _struct*)v->ref;
@@ -213,7 +214,7 @@ struct value *value_at(struct value *v, const char *s)
   return &_struct->member[i].value;
 }
 
-struct value *value_atw(struct value *v, const wchar_t *s)
+struct value * value_atw(struct value *v, const wchar_t *s)
 {
   const char *t = soap_wchar2s(NULL, s);
   struct value *u = value_at(v, t);
@@ -221,7 +222,7 @@ struct value *value_atw(struct value *v, const wchar_t *s)
   return u;
 }
 
-struct member *nth_member(struct value *v, int n)
+struct member * nth_member(struct value *v, int n)
 {
   struct _struct *_struct = (struct _struct*)v->ref;
   if (n < 0 && _struct)
@@ -235,7 +236,7 @@ struct member *nth_member(struct value *v, int n)
   return &_struct->member[n];
 }
 
-struct value *nth_value(struct value *v, int n)
+struct value * nth_value(struct value *v, int n)
 {
   if (v->__type == SOAP_TYPE__struct)
   {
@@ -251,9 +252,9 @@ struct value *nth_value(struct value *v, int n)
     if (v->__type != SOAP_TYPE__array || v->ref == NULL)
     {
       struct _array *_array = (struct _array*)soap_malloc(v->soap, sizeof(struct _array));
-      v->ref = _array;
       if (!_array)
         return NULL;
+      v->ref = _array;
       soap_default__array(v->soap, _array);
     }
     data = &((struct _array*)v->ref)->data;
@@ -269,6 +270,8 @@ struct value *nth_value(struct value *v, int n)
     {
       int newsize = size2k(data->__size = n + 1);
       data->value = (struct value*)soap_malloc(v->soap, sizeof(struct value) * newsize);
+      if (!data->value)
+        return NULL;
       for (i = 0; i < newsize; i++)
         soap_default_value(v->soap, &data->value[i]);
     }
@@ -299,7 +302,8 @@ void set_struct(struct value *v)
     v->ref = (struct _struct*)soap_malloc(v->soap, sizeof(struct _struct));
   v->__type = SOAP_TYPE__struct;
   v->__any = NULL;
-  soap_default__struct(v->soap, (struct _struct*)v->ref);
+  if (v->ref)
+    soap_default__struct(v->soap, (struct _struct*)v->ref);
 }
 
 void set_size(struct value *v, int n)
@@ -330,22 +334,31 @@ void set_size(struct value *v, int n)
   }
 }
 
-int has_size(struct value *v)
+int has_size(const struct value *v)
 {
   if (v->__type == SOAP_TYPE__array && v->ref)
-    return ((struct _array*)v->ref)->data.__size;
+    return ((const struct _array*)v->ref)->data.__size;
   if (v->__type == SOAP_TYPE__struct && v->ref)
-    return ((struct _struct*)v->ref)->__size;
+    return ((const struct _struct*)v->ref)->__size;
   return 0;
 }
 
-int nth_at(struct value *v, const char *s)
+int is_empty(const struct value *v)
+{
+  if (v->__type == SOAP_TYPE__array && v->ref)
+    return ((const struct _array*)v->ref)->data.__size == 0;
+  if (v->__type == SOAP_TYPE__struct && v->ref)
+    return ((const struct _struct*)v->ref)->__size == 0;
+  return 1;
+}
+
+int nth_at(const struct value *v, const char *s)
 {
   if (s == NULL)
     return -1;
   if (v->__type == SOAP_TYPE__struct)
   {
-    struct _struct *_struct = (struct _struct*)v->ref;
+    const struct _struct *_struct = (const struct _struct*)v->ref;
     int i;
     if (s == NULL)
       s = "";
@@ -357,7 +370,7 @@ int nth_at(struct value *v, const char *s)
   return -1;
 }
 
-int nth_atw(struct value *v, const wchar_t *s)
+int nth_atw(const struct value *v, const wchar_t *s)
 {
   const char *t;
   int i;
@@ -369,7 +382,7 @@ int nth_atw(struct value *v, const wchar_t *s)
   return i;
 }
 
-int nth_nth(struct value *v, int n)
+int nth_nth(const struct value *v, int n)
 {
   if (v->__type == SOAP_TYPE__array && v->ref)
   {
@@ -379,74 +392,75 @@ int nth_nth(struct value *v, int n)
   return -1;
 }
 
-_boolean is_null(struct value *v)
+_boolean is_null(const struct value *v)
 {
   return v->__type == 0 && !(v->__any && *v->__any);
 }
 
-_boolean is_int(struct value *v)
+_boolean is_int(const struct value *v)
 {
   return v->__type == SOAP_TYPE__i4 || v->__type == SOAP_TYPE__int;
 }
 
-_boolean is_double(struct value *v)
+_boolean is_double(const struct value *v)
 {
   return v->__type == SOAP_TYPE__double;
 }
 
-_boolean is_number(struct value *v)
+_boolean is_number(const struct value *v)
 {
   return v->__type == SOAP_TYPE__i4 || v->__type == SOAP_TYPE__int || v->__type == SOAP_TYPE__double;
 }
 
-_boolean is_string(struct value *v)
+_boolean is_string(const struct value *v)
 {
   return v->__type == SOAP_TYPE__string || (v->__any && *v->__any);
 }
 
-_boolean is_bool(struct value *v)
+_boolean is_bool(const struct value *v)
 {
   return v->__type == SOAP_TYPE__boolean;
 }
 
-_boolean is_true(struct value *v)
+_boolean is_true(const struct value *v)
 {
   return v->__type == SOAP_TYPE__boolean && *(_boolean*)v->ref;
 }
 
-_boolean is_false(struct value *v)
+_boolean is_false(const struct value *v)
 {
   return v->__type == SOAP_TYPE__boolean && !*(_boolean*)v->ref;
 }
 
-_boolean is_array(struct value *v)
+_boolean is_array(const struct value *v)
 {
   return v->__type == SOAP_TYPE__array;
 }
 
-_boolean is_struct(struct value *v)
+_boolean is_struct(const struct value *v)
 {
   return v->__type == SOAP_TYPE__struct;
 }
 
-_boolean is_dateTime(struct value *v)
+_boolean is_dateTime(const struct value *v)
 {
   return v->__type == SOAP_TYPE__dateTime_DOTiso8601;
 }
 
-_boolean is_base64(struct value *v)
+_boolean is_base64(const struct value *v)
 {
   return v->__type == SOAP_TYPE__base64;
 }
 
-struct params *new_params(struct soap *soap)
+struct params * new_params(struct soap *soap)
 {
   struct params *p = soap_malloc(soap, sizeof(struct params));
-  soap_default_params(soap, p);
+  if (p)
+    soap_default_params(soap, p);
   return p;
 }
 
-struct value *nth_param(struct params *p, int n)
+struct value * nth_param(struct params *p, int n)
 {
   int i = 0;
   if (n < 0)
@@ -459,6 +473,8 @@ struct value *nth_param(struct params *p, int n)
   {
     int newsize = size2k(p->__size = n + 1);
     p->param = (struct param*)soap_malloc(p->soap, sizeof(struct param) * newsize);
+    if (!p->param)
+      return NULL;
     for (i = 0; i < newsize; i++)
       soap_default_param(p->soap, &p->param[i]);
   }
