@@ -5,7 +5,7 @@
 
 --------------------------------------------------------------------------------
 gSOAP XML Web services tools
-Copyright (C) 2000-2016, Robert van Engelen, Genivia Inc. All Rights Reserved.
+Copyright (C) 2000-2017, Robert van Engelen, Genivia Inc. All Rights Reserved.
 This software is released under one of the following licenses:
 GPL or Genivia's license for commercial use.
 --------------------------------------------------------------------------------
@@ -41,7 +41,7 @@ A commercial use license is available from Genivia, Inc., contact@genivia.com
 #include "httpda.h"
 #endif
 
-#define WSDL2H_VERSION "2.8.30"
+#define WSDL2H_VERSION "2.8.60"
 
 #ifdef WIN32
 # pragma warning(disable : 4996)
@@ -95,6 +95,7 @@ extern int _flag,
            bflag,
 	   cflag,
 	   c11flag,
+	   Dflag,
 	   dflag,
 	   eflag,
 	   fflag,
@@ -104,10 +105,12 @@ extern int _flag,
 	   kflag,
 	   mflag,
 	   Mflag,
+	   Oflag,
 	   pflag,
 	   Pflag,
 	   Rflag,
 	   sflag,
+	   sflag,
 	   Uflag,
 	   uflag,
 	   vflag,
@@ -132,6 +135,7 @@ extern int proxy_port;
 
 extern const char *service_prefix;
 extern const char *schema_prefix;
+extern const char *soap_context;
 
 extern const char elementformat[];
 extern const char pointerformat[];
@@ -149,6 +153,9 @@ extern const char schemaformat[];
 extern const char serviceformat[];
 extern const char paraformat[];
 extern const char anonformat[];
+extern const char sizeparaformat[];
+extern const char pointertemplateparaformat[];
+
 extern const char copyrightnotice[];
 extern const char licensenotice[];
 
