@@ -45,15 +45,19 @@ extern int is_builtin_qname(const char*);
 ////////////////////////////////////////////////////////////////////////////////
 
 int soap__header::traverse(wsdl__definitions& definitions)
-{ if (vflag)
+{
+  if (vflag)
     cerr << "    Analyzing soap header in wsdl namespace '" << (definitions.targetNamespace?definitions.targetNamespace:"") << "'" << endl;
   messageRef = NULL;
   partRef = NULL;
   const char *token = qname_token(message, definitions.targetNamespace);
   if (token)
-  { for (vector<wsdl__message>::iterator message = definitions.message.begin(); message != definitions.message.end(); ++message)
-    { if ((*message).name && !strcmp((*message).name, token))
-      { messageRef = &(*message);
+  {
+    for (vector<wsdl__message>::iterator message = definitions.message.begin(); message != definitions.message.end(); ++message)
+    {
+      if ((*message).name && !strcmp((*message).name, token))
+      {
+	messageRef = &(*message);
         if (vflag)
 	  cerr << "     Found soap header part '" << (part?part:"") << "' message '" << (token?token:"") << "'" << endl;
         break;
@@ -61,14 +65,20 @@ int soap__header::traverse(wsdl__definitions& definitions)
     }
   }
   if (!messageRef)
-  { for (vector<wsdl__import>::iterator import = definitions.import.begin(); import != definitions.import.end(); ++import)
-    { wsdl__definitions *importdefinitions = (*import).definitionsPtr();
+  {
+    for (vector<wsdl__import>::iterator import = definitions.import.begin(); import != definitions.import.end(); ++import)
+    {
+      wsdl__definitions *importdefinitions = (*import).definitionsPtr();
       if (importdefinitions)
-      { token = qname_token(message, importdefinitions->targetNamespace);
+      {
+	token = qname_token(message, importdefinitions->targetNamespace);
         if (token)
-        { for (vector<wsdl__message>::iterator message = importdefinitions->message.begin(); message != importdefinitions->message.end(); ++message)
-          { if ((*message).name && !strcmp((*message).name, token))
-            { messageRef = &(*message);
+        {
+	  for (vector<wsdl__message>::iterator message = importdefinitions->message.begin(); message != importdefinitions->message.end(); ++message)
+          {
+	    if ((*message).name && !strcmp((*message).name, token))
+            {
+	      messageRef = &(*message);
               if (vflag)
 	        cerr << "     Found soap header part '" << (part?part:"") << "' message '" << (token?token:"") << "'" << endl;
               break;
@@ -79,10 +89,13 @@ int soap__header::traverse(wsdl__definitions& definitions)
     }
   }
   if (messageRef)
-  { if (part)
-    { for (vector<wsdl__part>::iterator pt = messageRef->part.begin(); pt != messageRef->part.end(); ++pt)
+  {
+    if (part)
+    {
+      for (vector<wsdl__part>::iterator pt = messageRef->part.begin(); pt != messageRef->part.end(); ++pt)
         if ((*pt).name && !strcmp((*pt).name, part))
-	{ partRef = &(*pt);
+	{
+	  partRef = &(*pt);
 	  break;
         }
     }
@@ -97,19 +110,23 @@ int soap__header::traverse(wsdl__definitions& definitions)
 }
 
 void soap__header::messagePtr(wsdl__message *message)
-{ messageRef = message;
+{
+  messageRef = message;
 }
 
 wsdl__message *soap__header::messagePtr() const
-{ return messageRef;
+{
+  return messageRef;
 }
 
 void soap__header::partPtr(wsdl__part *part)
-{ partRef = part;
+{
+  partRef = part;
 }
 
 wsdl__part *soap__header::partPtr() const
-{ return partRef;
+{
+  return partRef;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -119,15 +136,19 @@ wsdl__part *soap__header::partPtr() const
 ////////////////////////////////////////////////////////////////////////////////
 
 int soap__headerfault::traverse(wsdl__definitions& definitions)
-{ if (vflag)
+{
+  if (vflag)
     cerr << "    Analyzing soap headerfault in wsdl namespace '" << (definitions.targetNamespace?definitions.targetNamespace:"") << "'" << endl;
   messageRef = NULL;
   partRef = NULL;
   const char *token = qname_token(message, definitions.targetNamespace);
   if (token)
-  { for (vector<wsdl__message>::iterator message = definitions.message.begin(); message != definitions.message.end(); ++message)
-    { if ((*message).name && !strcmp((*message).name, token))
-      { messageRef = &(*message);
+  {
+    for (vector<wsdl__message>::iterator message = definitions.message.begin(); message != definitions.message.end(); ++message)
+    {
+      if ((*message).name && !strcmp((*message).name, token))
+      {
+	messageRef = &(*message);
         if (vflag)
 	  cerr << "     Found soap headerfault part '" << (part?part:"") << "' message '" << (token?token:"") << "'" << endl;
         break;
@@ -135,14 +156,20 @@ int soap__headerfault::traverse(wsdl__definitions& definitions)
     }
   }
   else
-  { for (vector<wsdl__import>::iterator import = definitions.import.begin(); import != definitions.import.end(); ++import)
-    { wsdl__definitions *importdefinitions = (*import).definitionsPtr();
+  {
+    for (vector<wsdl__import>::iterator import = definitions.import.begin(); import != definitions.import.end(); ++import)
+    {
+      wsdl__definitions *importdefinitions = (*import).definitionsPtr();
       if (importdefinitions)
-      { token = qname_token(message, importdefinitions->targetNamespace);
+      {
+	token = qname_token(message, importdefinitions->targetNamespace);
         if (token)
-        { for (vector<wsdl__message>::iterator message = importdefinitions->message.begin(); message != importdefinitions->message.end(); ++message)
-          { if ((*message).name && !strcmp((*message).name, token))
-            { messageRef = &(*message);
+        {
+	  for (vector<wsdl__message>::iterator message = importdefinitions->message.begin(); message != importdefinitions->message.end(); ++message)
+          {
+	    if ((*message).name && !strcmp((*message).name, token))
+            {
+	      messageRef = &(*message);
               if (vflag)
 	        cerr << "     Found soap headerfault part '" << (part?part:"") << "' message '" << (token?token:"") << "'" << endl;
               break;
@@ -153,10 +180,13 @@ int soap__headerfault::traverse(wsdl__definitions& definitions)
     }
   }
   if (messageRef)
-  { if (part)
-    { for (vector<wsdl__part>::iterator pt = messageRef->part.begin(); pt != messageRef->part.end(); ++pt)
+  {
+    if (part)
+    {
+      for (vector<wsdl__part>::iterator pt = messageRef->part.begin(); pt != messageRef->part.end(); ++pt)
         if ((*pt).name && !strcmp((*pt).name, part))
-	{ partRef = &(*pt);
+	{
+	  partRef = &(*pt);
 	  break;
         }
     }
@@ -169,19 +199,23 @@ int soap__headerfault::traverse(wsdl__definitions& definitions)
 }
 
 void soap__headerfault::messagePtr(wsdl__message *message)
-{ messageRef = message;
+{
+  messageRef = message;
 }
 
 wsdl__message *soap__headerfault::messagePtr() const
-{ return messageRef;
+{
+  return messageRef;
 }
 
 void soap__headerfault::partPtr(wsdl__part *part)
-{ partRef = part;
+{
+  partRef = part;
 }
 
 wsdl__part *soap__headerfault::partPtr() const
-{ return partRef;
+{
+  return partRef;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -191,18 +225,25 @@ wsdl__part *soap__headerfault::partPtr() const
 ////////////////////////////////////////////////////////////////////////////////
 
 int wsoap__header::traverse(wsdl__definitions& definitions)
-{ if (vflag)
+{
+  if (vflag)
     cerr << "    Analyzing soap header in wsdl namespace '" << (definitions.targetNamespace?definitions.targetNamespace:"") << "'" << endl;
   elementRef = NULL;
   // WSDL 2.0
   if (element)
-  { if (definitions.types)
-    { for (vector<xs__schema*>::iterator schema = definitions.types->xs__schema_.begin(); schema != definitions.types->xs__schema_.end(); ++schema)
-      { const char *token = qname_token(element, (*schema)->targetNamespace);
+  {
+    if (definitions.types)
+    {
+      for (vector<xs__schema*>::iterator schema = definitions.types->xs__schema_.begin(); schema != definitions.types->xs__schema_.end(); ++schema)
+      {
+	const char *token = qname_token(element, (*schema)->targetNamespace);
         if (token)
-        { for (vector<xs__element>::iterator element = (*schema)->element.begin(); element != (*schema)->element.end(); ++element)
-          { if ((*element).name && !strcmp((*element).name, token))
-            { elementRef = &(*element);
+        {
+	  for (vector<xs__element>::iterator element = (*schema)->element.begin(); element != (*schema)->element.end(); ++element)
+          {
+	    if ((*element).name && !strcmp((*element).name, token))
+            {
+	      elementRef = &(*element);
               if (vflag)
                 cerr << "   Found soap header element '" << (token?token:"") << "'" << endl;
               break;
@@ -212,7 +253,8 @@ int wsoap__header::traverse(wsdl__definitions& definitions)
       }
     }
     if (!elementRef)
-    { if (is_builtin_qname(element))
+    {
+      if (is_builtin_qname(element))
         definitions.builtinElement(element);
       else
         if (!Wflag)
@@ -223,9 +265,11 @@ int wsoap__header::traverse(wsdl__definitions& definitions)
 }
 
 void wsoap__header::elementPtr(xs__element *element)
-{ elementRef = element;
+{
+  elementRef = element;
 }
 
 xs__element *wsoap__header::elementPtr() const
-{ return elementRef;
+{
+  return elementRef;
 }
